Chapter class

Chapter class.

Constructors

Chapter(Map? _allProperties)
Creates a new Chapter instance

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getAllProperties() → Map?
Returns all properties found.
getEnd() → int?
Returns end.
getEndTime() → String?
Returns end time.
getId() → int?
Returns id.
getNumberProperty(String key) → num?
Returns the chapter property associated with the key.
getProperty(String key) → dynamic
Returns the chapter property associated with the key.
getStart() → int?
Returns start.
getStartTime() → String?
Returns start time.
getStringProperty(String key) → String?
Returns the chapter property associated with the key.
getTags() → Map?
Returns all tags.
getTimeBase() → String?
Returns time base.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

keyEnd → const String
keyEndTime → const String
keyId → const String
keyStart → const String
keyStartTime → const String
keyTags → const String
keyTimeBase → const String