Statistics class

Statistics entry for an FFmpeg execute session.

Constructors

Statistics(int _sessionId, int _videoFrameNumber, double _videoFps, double _videoQuality, int _size, double _time, double _bitrate, double _speed)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getBitrate() → double
getSessionId() → int
getSize() → int
getSpeed() → double
getTime() → double
getVideoFps() → double
getVideoFrameNumber() → int
getVideoQuality() → double
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setBitrate(double bitrate) → void
setSessionId(int sessionId) → void
setSize(int size) → void
setSpeed(double speed) → void
setTime(double time) → void
setVideoFps(double videoFps) → void
setVideoFrameNumber(int videoFrameNumber) → void
setVideoQuality(double videoQuality) → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited