StreamInformation class

Stream information class.

Constructors

StreamInformation(Map? _allProperties)
Creates a new StreamInformation instance

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getAllProperties() → Map?
Returns all properties found.
getAverageFrameRate() → String?
Returns average frame rate.
getBitrate() → String?
Returns bitrate.
getChannelLayout() → String?
Returns channel layout.
getCodec() → String?
Returns stream codec.
getCodecLong() → String?
Returns stream codec in long format.
getCodecTimeBase() → String?
Returns codec time base.
getDisplayAspectRatio() → String?
Returns display aspect ratio.
getFormat() → String?
Returns stream format.
getHeight() → int?
Returns height.
getIndex() → int?
Returns stream index.
getNumberProperty(String key) → num?
Returns the stream property associated with the key.
getProperty(String key) → dynamic
Returns the stream property associated with the key.
getRealFrameRate() → String?
Returns real frame rate.
getSampleAspectRatio() → String?
Returns sample aspect ratio.
getSampleFormat() → String?
Returns sample format.
getSampleRate() → String?
Returns sample rate.
getStringProperty(String key) → String?
Returns the stream property associated with the key.
getTags() → Map?
Returns all tags.
getTimeBase() → String?
Returns time base.
getType() → String?
Returns stream type.
getWidth() → int?
Returns width.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

keyAverageFrameRate → const String
keyBitRate → const String
keyChannelLayout → const String
keyCodec → const String
keyCodecLong → const String
keyCodecTimeBase → const String
keyDisplayAspectRatio → const String
keyFormat → const String
keyHeight → const String
keyIndex → const String
keyRealFrameRate → const String
keySampleAspectRatio → const String
keySampleFormat → const String
keySampleRate → const String
keyTags → const String
keyTimeBase → const String
keyType → const String
keyWidth → const String